<div id="table-list">
  <div class="row center-align">
    {% include 'crudlfap/_pagination.html' %}
  </div>

  <table class="table striped">
    <thead class="thead-inverse">
      <tr>
        {% for field in view.fields %}
        <th>{{ view.model._meta.get_field(field).verbose_name.capitalize() }}</th>
        {% endfor %}
        <th></th>
      </tr>
    </thead>
    <tbody>
      {% for object in object_list %}
      <tr>
        {% for field in view.fields %}
          <td>{{ getattr(object, field) }}</td>
        {% endfor %}
        <td>
          {% for view in view.router.get_menu('object', request, object=object) %}
            {% with extra_class='btn-small' %}
            {% include 'crudlfap/_action.html' %}
            {% endwith %}
          {% endfor %}
        </td>
      </tr>
      {% endfor %}
    </tbody>
  </table>
</div>
